Documentation
¶
Index ¶
Constants ¶
const BuildFailedState = "FAILED"
const BuildStagedState = "STAGED"
const KpackLifecycleType = "kpack"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Build ¶
type Build struct {
State string `json:"state"`
Error string `json:"error"`
Lifecycle Lifecycle `json:"lifecycle"`
}
Build represents the payload that will be sent to CF API server when a kpack Build has been updated.
func NewBuild ¶
func NewBuild(build *kpack_build.Build) Build
type Lifecycle ¶
type Lifecycle struct {
Type string `json:"type"`
Data LifecycleData `json:"data"`
}
type LifecycleData ¶
Click to show internal directories.
Click to hide internal directories.